@@ -8,9 +8,9 @@
 # http://opensource.org/licenses/LGPL-3.0
 # Copyright (c) 2015-9, Neil Freeman <contact@fakeisthenewreal.org>
 
-from .censusgeocode import CensusGeocode, benchmarks, vintages
+from .censusgeocode import CensusGeocode
 
-__version__ = '0.4.4'
+__version__ = '0.5.1'
 
 cg = CensusGeocode()
 
